@@ -24,7 +24,7 @@ Leyland::Context - The working environment of an HTTP request and Leyland respon
 
 =head1 VERSION
 
-version 0.001006
+version 0.001007
 
 =head1 SYNOPSIS
 
@@ -547,13 +547,29 @@ The default C<finalize()> method provided by this class does not do anything.
 
 sub finalize { 1 } # meant to be overridden
 
+=head2 accepts( $mime )
+
+Returns a true value if the client accepts the provided MIME type.
+
+=cut
+
+sub accepts {
+	my ($self, $mime) = @_;
+
+	foreach (@{$self->wanted_mimes}) {
+		return 1 if $_->{mime} eq $mime;
+	}
+
+	return;
+}
+
 =head1 INTERNAL METHODS
 
 The following methods are only to be used internally:
 
 =cut
 
-sub _build_res { shift->new_response(200, [ 'Content-Type' => 'text/html' ]) }
+sub _build_res { shift->new_response(200) }
 
 sub _build_mimes {
 	my $self = shift;
@@ -909,4 +925,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
\ No newline at end of file
+__PACKAGE__->meta->make_immutable;
